use Mail::SpamAssassin;
use DBI;

my $spamtest;

sub getStatusLine {
	my ($status) = @_;
	my @test_names = sort(@{$status->{test_names_hit}});

	my $line = ($status->is_spam() ? "Yes, " : "No, ");
	$line .= $status->{score} . "," . $status->{conf}->{required_score};

	foreach $_ (@test_names) {
		$line .= "," . $_ . ": " . $status->{conf}->{scores}->{$_};
	}

	return $line;
}


sub initEngine
{
	my ($sa_dir, $db_dir, $enableSurbl, $enableDebug) = @_;
	my $bayes_db = "$db_dir/bayes";
        my $rules_dir = "$sa_dir/rules";
        my $prefix_dir = "$sa_dir/site";
	my $rv = 1;
	
	$spamtest = new Mail::SpamAssassin ({
	    rules_filename    => $rules_dir,
	    site_rules_filename => $rules_dir,
	    userstate_dir     => $bayes_db,
	    local_tests_only  => !($enableSurbl),
	    debug             => $enableDebug,
	    dont_copy_prefs   => 1,
	    PREFIX            => $prefix_dir,
	    DEF_RULES_DIR     => $rules_dir,
	    LOCAL_RULES_DIR   => $rules_dir
	});

	$spamtest->{conf}->{bayes_store_module} = "Mail::SpamAssassin::BayesStore::SDBM";
	$spamtest->{conf}->{auto_whitelist_factory} = "Mail::SpamAssassin::DBBasedAddrList";

	$spamtest->compile_now(0);
	$spamtest->init_learner();

	return $rv;
	
}

sub checkMessage
{
	my ($spam_file_name) = @_;

  	my $spam_file;
	open($spam_file, $spam_file_name);

	my $mail = $spamtest->parse($spam_file);

	close($spam_file);

	my $status = $spamtest->check($mail);
	my $line = getStatusLine($status);

	$status->finish();
	$mail->finish();

	return $line; 
};

sub learnMessage
{
	my ($spam_file_name, $isspam) = @_;	
	
	my $spam_file;
	open($spam_file, $spam_file_name);

	my $mail = $spamtest->parse($spam_file);
	
	close($spam_file);

	my $status = $spamtest->learn($mail, undef, $isspam, 0);
	
	$status->finish();
	$mail->finish();
}


sub getBayesStatistics
{
	$spamtest->{bayes_scanner}->{store}->tie_db_readonly();
	my @vars = $spamtest->{bayes_scanner}->{store}->get_storage_variables();
	$spamtest->{bayes_scanner}->{store}->untie_db();
	return @vars;
	
}
